MemoryStorage class
In-memory TranslationStorage backed by a simple Map.
Useful for testing and debug scenarios where persistence is not needed.
- Implemented types
Constructors
Properties
Methods
-
clear(
) → void - Clear all stored data.
-
get(
String key) → Future< String?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String key) → Future< void> -
override
-
set(
String key, String value) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited